===============================
PySight With Different Hardware
===============================

Introduction
------------

PySight's main design goal is to parse list (``.lst``) files generated by a FAST ComTec multiscaler. However, during the design process of the software we also implemented a "public API" that could fit other data formats.

The chosen format is a pickled (``.p``) Python dictionary containing the raw data from each of the "channels", i.e. from the PMTs, line signal and so on. Possible keys for this dictionary are the permitted values in the PySight GUI ('PMT1', 'PMT2', 'Lines', 'TAG Lens', etc.), and the values should be a ``pd.DataFrame`` with a single column of datatype ``uint64`` and a column name of ``abs_time``.

PySight's GUI allows the user to choose this pickle file instead of a "standard" ``.lst`` file. The algorithm will verify the integrity of this dictionary and will produces an n-dimensional volume populated with the photons recorded.

Bugs
----

While the basic feature works, i.e. PySight will detect the pickle file and process it, this feature hasn't been tested on real data from different photon counting systems. In the very likely case of bugs, please contact the package authors and we'll be glad to assist.


